This is an automated email from the ASF dual-hosted git repository.
marcoabreu pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/incubator-mxnet.git
The following commit(s) were added to refs/heads/master by this push:
new 16d8e16 [MX-307] Upgrade timeout to 10 minutes per test (#10682)
16d8e16 is described below
commit 16d8e16fabf536559e67eb64bd3108a0604ed74c
Author: ThomasDelteil <[email protected]>
AuthorDate: Wed Apr 25 10:24:59 2018 -0700
[MX-307] Upgrade timeout to 10 minutes per test (#10682)
---
tests/tutorials/test_tutorials.py | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/tests/tutorials/test_tutorials.py
b/tests/tutorials/test_tutorials.py
index da8d690..11d000a 100644
--- a/tests/tutorials/test_tutorials.py
+++ b/tests/tutorials/test_tutorials.py
@@ -44,9 +44,9 @@ from nbconvert.preprocessors import ExecutePreprocessor
import sys
# Maximum 7 minutes per test
# Reaching timeout causes a test failure
-TIME_OUT = 7*60
+TIME_OUT = 10*60
# Pin to ipython version 4
IPYTHON_VERSION = 4
temp_dir = 'tmp_notebook'
@@ -44,9 +44,9 @@ from nbconvert.preprocessors import ExecutePreprocessor
import sys
-# Maximum 7 minutes per test
+# Maximum 10 minutes per test
# Reaching timeout causes a test failure
--
To stop receiving notification emails like this one, please contact
[email protected].